#bmi.r
N <- c(252,15,131,21,57,12,24,8,46,9,35,5,12,1,5,1)
cc <- factor(c(1,1,2,2,1,1,2,2,1,1,2,2,1,1,2,2))
bmi <- factor(c(1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2))
race <- factor(rep(1:4,c(4,4,4,4)))

#data
array(N,c(2,2,4))
cbind(N,cc,bmi,race)

#model  -- case/control(cc), bmi, race and interactions
f <- glm(N~cc+bmi+race+cc:bmi+cc:race+bmi:race,family=poisson)
summary(f)
e <- fitted(f)
cbind(N,e,cc,bmi,race)
X2 <- sum(((N-e)^2/e))
pvalue <- 1-pchisq(X2,3)
cbind(X2,pvalue)

#race:cc eliminated
f1 <- glm(N~cc+bmi+cc*bmi+race*bmi,family=poisson)
summary(f1)
e <- fitted(f1)
cbind(N,e,cc,bmi)
X2 <- sum(((N-e)^2/e))
pvalue <- 1-pchisq(X2,3)
cbind(X2,pvalue)
anova(f1,f,test="Chisq")

#reduced table -- summed over race
N0 <- c(367,37,195,35)

#analysis
cc <- c(1,1,0,0)
bmi <- c(1,0,1,0)
cbind(N0,cc,bmi)
f1 <- glm(N0~cc+bmi,family=poisson)
summary(f1)
e <- fitted(f1)
cbind(cc,bmi,N0,e)

#evaluation
X2 <- sum(((N0-e)^2/e))
pvalue <- 1-pchisq(X2,3)
cbind(X2,pvalue)
or <- (367*35)/(195*37)
v <- sum(1/N0)
x2 <- (log(or)/sqrt(v))^2
pvalue <- 1-pchisq(x2,1)
round(cbind(or,v,pvalue),3)


#plot
N <- c(252,15,131,21,57,12,24,8,46,9,35,5,12,1,5,1)
cc <- factor(c(1,1,2,2,1,1,2,2,1,1,2,2,1,1,2,2))
bmi <- factor(c(1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2))
race <- factor(rep(1:4,c(4,4,4,4)))
bmi0 <- tapply(N[bmi==1],race[bmi==1],sum)
bmi1 <- tapply(N[bmi==2],race[bmi==2],sum)
tab <- log(rbind(bmi0,bmi1))
matplot(1:4,t(tab),type="b",xlab="ethnicity",ylab="log(count)",pch=16)
title("log(counts) by ethnicity")
legend(2,6,c("bmi <= 29","bmi > 29"),1:2)
bmi.ratio <- exp(mean(log(bmi0)-log(bmi1)))
bmi.ratio
