#linear.r

rm(list=ls())

linear <- read.table("~/Dropbox/r-case.studies/linear.data",header=TRUE)
attach(linear)
round(rbind(summary(bwt),
summary(wt),
summary(ht),
summary(gest)),2)

#correlation array
round(cor(linear),2)

#regression analysis
f <- glm(bwt~wt+ht)
summary(f)

#residuals
f1 <- glm(bwt~ht)
summary(f1)
bwt.ht <- f1$residuals
f2 <- glm(wt~ht)
cor(bwt.ht,ht)
summary(f2)
wt.ht <- f2$residuals
cor(wt.ht,ht)
f3 <- glm(bwt.ht~wt.ht)
summary(f3)

#multiple correlation coefficient
n <- length(bwt)
bwt.hat <- fitted(f)
r <- cor(bwt,bwt.hat)^2
ss0 <- sum((bwt-mean(bwt))^2)
ss1 <- sum((bwt-fitted(f))^2)
r2 <- (ss0-ss1)/ss0

#relationship to the estimated variances
v0 <- ss0/(n-1) 
v1 <- ss1/(n-2)
r3 <- (v0-v1)/v0
cbind(r,r2,r3)

#partial correlation coefficients
r0 <- cor(bwt.ht,wt.ht)
ri <- cor(bwt,wt)
rj <- cor(bwt,ht)
rij <- cor(wt,ht)
r1 <- (ri-rj*rij)/sqrt((1-rij^2)*(1-rj^2))
cbind(r0,r1)

#evaluation
cbind(cor(bwt.hat,bwt),cor(bwt.hat,bwt)^2)
cbind(cor(wt,ht),cor(bwt.ht,wt.ht))

#plot -- observed versus estimated values
plot(fitted(f),bwt,main="observed versus estimated")
abline(0,1,lwd=2)
text(7.4,11.0,"correlation(obs,est) = 0.076")



