#perinatal.r
#perinatal infant deaths
rm(list=ls())

perinatal <- read.table("~/Dropbox/r-case.studies/perinatal.data",header=TRUE)
attach(perinatal)
bwt <- c(low,low)
race <- c(rep(1,35),rep(0,35))
pop <- c(wpop,bpop)
deaths <- c(wdeaths,bdeaths)
cbind(bwt,race,deaths,pop)

#analysis -- simple linear regression estimates
b.rate <- bdeaths/bpop
w.rate <- wdeaths/wpop
R <- b.rate/w.rate
round(cbind(w.rate,b.rate,R),3)

f <- glm(b.rate~-1+w.rate)
round(summary(f)$coefficients[1,],3)

#weighted average and confidence interval
v <- 1/wdeaths+1/bdeaths
w <- 1/v
lograte <- sum(w*log(R))/sum(w)
se <- sqrt(1/sum(w))
round(c(lograte-1.960*se,lograte,lograte+1.960*se),3)
round(exp(c(lograte-1.960*se,lograte,lograte+1.960*se)),3)

#analysis -- fifth degree polynomial
f <- glm(deaths~race+poly(bwt,5)+offset(log(pop)),family=poisson)
summary(f)

#evaluation
ex <- fitted(f)
X2 <- sum((deaths-ex)^2/ex)
pvalue <- 1-pchisq(X2,63)
cbind(X2,pvalue)

#confidence intervals
eval <- round(summary(f)$coefficients[2,],3)
lower <- eval[1]-1.960*eval[2]
upper <- eval[1]+1.960*eval[2]
round(cbind(lower,eval[1],upper),3)
round(exp(cbind(lower,eval[1],upper)),3)

#ratio ratios
rr.adj <- exp(eval[1])
rr.unadj <- (sum(wdeaths)/sum(wpop))/(sum(bdeaths)/sum(bpop))
cbind(rr.adj,rr.unadj)

