#predict.r
rm(list=ls())

ci <- function(m,v) {
A <- m-1.960*sqrt(v)
B <- m+1.960*sqrt(v)
round(cbind(A,B),5)
}

predict <- read.table("~/Dropbox/r-case.studies/predict.data",header=TRUE)
attach(predict)
summary(predict)
#cbind(chd,sex,sbp,dbp,chol,smk,bmi,age)


#cholesterol included
f <- glm(chd~sex+sbp+dbp+chol+factor(smk)+bmi+age,family=binomial)
p <- fitted(f)
summary(f)
log.f <- f$deviance/2

#cholesterol excluded
f0 <- glm(chd~sex+sbp+dbp+factor(smk)+bmi+age,family=binomial)
summary(f0)
p0 <- fitted(f0)
log.f0 <- f0$deviance/2
x2 <- -2*(log.f-log.f0)
pvalue <- 1-pchisq(x2,1)
round(cbind(log.f,log.f0,x2,pvalue),3)

#Net reclassification index -- nri
n11 <- sum(ifelse(p[chd==1]>p0[chd==1],1,0))
n12 <- sum(ifelse(p[chd==1]<p0[chd==1],1,0))
n21 <- sum(ifelse(p[chd==0]>p0[chd==0],1,0))
n22 <- sum(ifelse(p[chd==0]<p0[chd==0],1,0))
matrix(cbind(n11,n21,n12,n22),2,2)
up.chd <- n11/(n11+n12)
down.chd <- 1-up.chd
up.nochd <- n21/(n21+n22)
down.nochd <- 1-up.nochd
round(cbind(up.chd,down.chd,up.nochd,down.nochd),3)
nri <- (up.chd-down.chd)+(down.nochd-up.nochd)
v <- 1/(n11+n12)+1/(n21+n22)
sd <- sqrt(v)
x2 <- nri^2/v
pvalue <- 1-pchisq(x2,1)
#summary values
round(cbind(nri,sd,x2,pvalue,ci(nri,v)),4)

#Integrative discrimination improvement --idi
p11 <- p[chd==1]
p01 <- p[chd==0]
p10 <- p0[chd==1]
p00 <- p0[chd==0]
round(cbind(mean(p11),mean(p10),mean(p01),mean(p00)),3)
idi <- (mean(p11)-mean(p10))-(mean(p01)-mean(p00))
n0 <- length(chd[chd==0])
n1 <- length(chd[chd==1])
v <- var(p11-p10)/n1+var(p01-p00)/n0
x2 <- idi^2/v
sd <- sqrt(v)
pvalue <- 1-pchisq(x2,1)
round(cbind(n1,n0,idi,sd,x2,pvalue,ci(idi,v)),4)


#covariance and correlation
#calculated from data and from expressions
#p = cholesterol included and p0 = cholesterol excluded

n <- n1+n0
P <- n1/n
#covariances -- cov(chd,p) and cov(chd,p0)
round(cbind(cov(chd,p),(mean(p11)-mean(p01))*P*(1-P)),4)
round(cbind(cov(chd,p0),(mean(p10)-mean(p00))*P*(1-P)),4)
#correlations -- cor(chd,p) and cor(chd,p0)
f <- (n-1)/n
round(cbind(cor(chd,p),(mean(p11)-mean(p01))*sqrt((P*(1-P))/(f*var(p)))),4)
round(cbind(cor(chd,p0),(mean(p10)-mean(p00))*sqrt((P*(1-P))/(f*var(p0)))),4)




