
#ses.r
rm(list=ls())

#three-way table
N <- c(38,40,34,90,58,91,54,167,88,260,45,57,54,99,80,140,77,275,90,391)
#data -- smoking by ses by age
data <- array(N,c(2,5,2))
data

#poisson model
age <- factor(c(1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2))
ses <- factor(rep(c(1,1,2,2,3,3,4,4,5,5,1,1,2,2,3,3,4,4,5,5)))
smk <- factor(rep(c(1,2),10))
cbind(N,age,ses,smk)

#Poisson regression model -- ses, smoking, age and interactions
f <- glm(N~smk+ses+age+smk:age+smk:ses+ses:age,family=poisson)
summary(f)
e <- fitted(f)
X2 <- sum((N-e)^2/e)
cbind(N,e)
pvalue <- 1-pchisq(X2,4)
cbind(X2,pvalue)

#analysis -- ses:age eliminated
f1 <- glm(N~smk+ses+age+smk:age+smk:ses,family=poisson)
summary(f1)
test <- f1$deviance-f$deviance
df <- f1$df.residual-f$df.residual
pvalue <- 1-pchisq(test,df)
round(cbind(f1$deviance,test,df,pvalue),3)
#alternatively
round(anova(f1,f,test="Chisq"),3)

#analysis -- smk:age eliminated
f2 <- glm(N~smk+ses+age+ses:age+smk:ses,family=poisson)
summary(f2)
test <- f2$deviance-f$deviance
df <- f1$df.residual-f$df.residual
pvalue <- 1-pchisq(test,df)
round(cbind(f2$deviance,test,df,pvalue),3)
#alternatively
round(anova(f2,f,test="Chisq"),3)

#analysis -- smk:age and ses:age eliminated
f3 <- glm(N~smk+ses+age+smk:ses,family=poisson)
summary(f3)
test <- f3$deviance-f$deviance
df <- f3$df.residual-f$df.residual
pvalue <- 1-pchisq(test,df)
round(cbind(f3$deviance,test,df,pvalue),3)
#alternatively
round(anova(f3,f,test="Chisq"),3)

#ses/age -- table
o <- apply(data,c(3,2),sum)
o
e <- outer(apply(o,1,sum),apply(o,2,sum))/sum(o)
round(e,1)

#calculation of summary values
x2 <- sum((o-e)^2/e)
pvalue <- 1-pchisq(x2,4)
cbind(x2,pvalue)
chisq.test(o)

#estimated values
p.o <- o[1,]/(o[1,]+o[2,])
r.o <- o[2,]/o[1,]
P.e <- sum(e[1,])/sum(e[1,]+e[2,])
R.e <- sum(e[2,])/sum(e[1,])
round(rbind(p.o,r.o),3)
round(rbind(R.e,P.e),3)
