#weibull.r
#analysis: two-sample comparison -- smokers/nonsmokers

rm(list=ls())
library(survival)

two <- read.table("~/Dropbox/r-case.studies/weibull.two.data",header=TRUE)
attach(two)
#cbind(t,cc,smoke)

#analysis
f <- survreg(Surv(t,cc)~smoke,dist="weibull")
summary(f)
f.like <- f$loglik[2]
f0 <- survreg(Surv(t,cc)~smoke,dist="exponential")
summary(f0)
f0.like <- f0$loglik[2]
#comparison
X2 <- 2*(f.like-f0.like)
pvalue <- 1-pchisq(X2,1)
round(cbind(f.like,f0.like,X2,pvalue),3)

#shape parameter
#log-likehood comparison
#smokers
f1 <- survreg(Surv(t[smoke==1],cc[smoke==1])~1,dist="weibull")
f1.like <- f1$loglik[2]
g1 <- 1/f1$scale
se1 <- sqrt(f1$var[2,2])
#nonsmokers
f0 <- survreg(Surv(t[smoke==0],cc[smoke==0])~1,dist="weibull")
f0.like <- f0$loglik[2]
g0 <- 1/f0$scale
se0 <- sqrt(f0$var[2,2])

#combined
f <- survreg(Surv(t,cc)~smoke,dist="weibull")
f.like <- f$loglik[2]
X2 <- 2*((f0.like+f1.like)-f.like)
pvalue <- 1-pchisq(X2,1)
round(cbind(f0.like,f1.like,f.like,X2,pvalue),4)

#chi-square test of difference
v <- se0^2+se1^2
x2 <- ((log(g0)-log(g1))/sqrt(v))^2
round(cbind(g1,g0,se0,se1,x2,pvalue),4)

#summary values
b <- -coef(f)
gamma <- 1/f$scale
lambda.0 <- exp(b[1]*gamma)
lambda.1 <- exp((b[1]+b[2])*gamma)
hr <- lambda.1/lambda.0
median.0 <- (log(2)/lambda.0)^(1/gamma)
median.1 <- (log(2)/lambda.1)^(1/gamma)
round(cbind(lambda.0,lambda.1,hr,median.0,median.1),4)


#Weibull multivariable analysis (cd4, beta and age)
rm(list=ls())

w.data <- read.table("~/Dropbox/r-case.studies/weibull.data",header=TRUE)
attach(w.data)
summary(w.data)
#cbind(t,cc,cd4,beta,age)

#cd4 only
f <- survreg(Surv(t,cc)~cd4,dist="weibull")
summary(f)

#summary values
gamma <- 1/f$scale
w.log <- -f$loglik[2]
b <- -coef(f)
lambda <- exp(b[1])
hr <- exp(b[2]*gamma)
hr.100 <- exp(b[2]*gamma)^100
cd4bar <- mean(cd4)
m <- (log(2)*exp(-(b[1]+b[2]*cd4bar)*gamma))^(1/gamma)
round(cbind(w.log,lambda,gamma,hr,hr.100,m),3)


#full model
f0 <- survreg(Surv(t,cc)~cd4+beta+age,dist="weibull")
summary(f0)
w.log <- f0$loglik[2]

#interaction model
f <- survreg(Surv(t,cc)~(cd4+beta+age)^2,dist="weibull")
summary(f)

#loglikehood comparison -- smokers versus nonsmokers
W.log <- f$loglik[2]
x2 <- 2*(W.log-w.log)
pvalue <- 1-pchisq(x2,3)
round(cbind(w.log,W.log,x2,pvalue),3)

